"""Unicode Properties from Unicode version 16.0.0 (autogen)."""
from __future__ import annotations

unicode_joining_group: dict[str, str] = {
    "^africanfeh": "\x00-\u08ba\u08bc-\U0010ffff",
    "^africannoon": "\x00-\u08bc\u08be-\U0010ffff",
    "^africanqaf": "\x00-\u08bb\u08bd-\u08c3\u08c5-\U0010ffff",
    "^ain": "\x00-\u0638\u063b-\u069f\u06a1-\u06fb\u06fd-\u075c\u0760-\u08b2\u08b4-\u08c2\u08c4-\U0010ffff",
    "^alaph": "\x00-\u070f\u0711-\U0010ffff",
    "^alef": "\x00-\u0621\u0624\u0626\u0628-\u0670\u0674\u0676-\u0772\u0775-\u086f\u0883-\U0010ffff",
    "^beh": "\x00-\u0627\u0629\u062c-\u066d\u066f-\u0678\u0681-\u074f\u0757-\u089f\u08a2-\u08b5\u08b9-\u08bd\u08c1-\U0010ffff",
    "^beth": "\x00-\u0711\u0713-\u072c\u072e-\U0010ffff",
    "^burushaskiyehbarree": "\x00-\u0779\u077c-\U0010ffff",
    "^dal": "\x00-\u062e\u0631-\u0687\u0691-\u06ed\u06ef-\u0758\u075b-\u08ad\u08af-\U00010ec1\U00010ec3-\U0010ffff",
    "^dalathrish": "\x00-\u0714\u0717-\u0729\u072b-\u072e\u0730-\U0010ffff",
    "^e": "\x00-\u0724\u0726-\U0010ffff",
    "^farsiyeh": "\x00-\u063c\u0640-\u06cb\u06cd\u06cf-\u0774\u0777-\U0010ffff",
    "^fe": "\x00-\u074e\u0750-\U0010ffff",
    "^feh": "\x00-\u0640\u0642-\u06a0\u06a7-\u075f\u0762-\u08a3\u08a5-\U0010ffff",
    "^finalsemkath": "\x00-\u0723\u0725-\U0010ffff",
    "^gaf": "\x00-\u063a\u063d-\u06a8\u06aa\u06ac-\u06ae\u06b5-\u0761\u0765-\u088c\u088e-\u08af\u08b1-\u08c1\u08c3-\u08c7\u08c9-\U0010ffff",
    "^gamal": "\x00-\u0712\u0715-\u072d\u072f-\U0010ffff",
    "^hah": "\x00-\u062b\u062f-\u0680\u0688-\u06be\u06c0-\u0756\u0759-\u076d\u0770-\u0771\u0773-\u077b\u077d-\u0889\u088b-\u08a1\u08a3-\u08c0\u08c2-\u08c4\u08c7-\U0010ffff",
    "^hanifirohingyakinnaya": "\x00-\U00010d18\U00010d1a-\U00010d1d\U00010d1f\U00010d21-\U00010d22\U00010d24-\U0010ffff",
    "^hanifirohingyapa": "\x00-\U00010d01\U00010d03-\U00010d08\U00010d0a-\U00010d1b\U00010d1d-\U0010ffff",
    "^he": "\x00-\u0716\u0718-\U0010ffff",
    "^heh": "\x00-\u0646\u0648-\U0010ffff",
    "^hehgoal": "\x00-\u06c0\u06c3-\U0010ffff",
    "^heth": "\x00-\u0719\u071b-\U0010ffff",
    "^kaf": "\x00-\u0642\u0644-\u06ab\u06af-\u077e\u0780-\u08b3\u08b5-\U00010ec3\U00010ec5-\U0010ffff",
    "^kaph": "\x00-\u071e\u0720-\U0010ffff",
    "^kashmiriyeh": "\x00-\u061f\u0621-\U0010ffff",
    "^khaph": "\x00-\u074d\u074f-\U0010ffff",
    "^knottedheh": "\x00-\u06bd\u06bf-\u06fe\u0700-\U0010ffff",
    "^lam": "\x00-\u0643\u0645-\u06b4\u06b9-\u0769\u076b-\u08a5\u08a7-\u08c6\u08c8-\U0010ffff",
    "^lamadh": "\x00-\u071f\u0721-\U0010ffff",
    "^malayalambha": "\x00-\u0865\u0867-\U0010ffff",
    "^malayalamja": "\x00-\u0860\u0862-\U0010ffff",
    "^malayalamlla": "\x00-\u0867\u0869-\U0010ffff",
    "^malayalamllla": "\x00-\u0868\u086a-\U0010ffff",
    "^malayalamnga": "\x00-\u085f\u0861-\U0010ffff",
    "^malayalamnna": "\x00-\u0863\u0865-\U0010ffff",
    "^malayalamnnna": "\x00-\u0864\u0866-\U0010ffff",
    "^malayalamnya": "\x00-\u0861\u0863-\U0010ffff",
    "^malayalamra": "\x00-\u0866\u0868-\U0010ffff",
    "^malayalamssa": "\x00-\u0869\u086b-\U0010ffff",
    "^malayalamtta": "\x00-\u0862\u0864-\U0010ffff",
    "^manichaeanaleph": "\x00-\U00010abf\U00010ac1-\U0010ffff",
    "^manichaeanayin": "\x00-\U00010ad8\U00010adb-\U0010ffff",
    "^manichaeanbeth": "\x00-\U00010ac0\U00010ac3-\U0010ffff",
    "^manichaeandaleth": "\x00-\U00010ac4\U00010ac6-\U0010ffff",
    "^manichaeandhamedh": "\x00-\U00010ad3\U00010ad5-\U0010ffff",
    "^manichaeanfive": "\x00-\U00010aeb\U00010aed-\U0010ffff",
    "^manichaeangimel": "\x00-\U00010ac2\U00010ac5-\U0010ffff",
    "^manichaeanheth": "\x00-\U00010acc\U00010ace-\U0010ffff",
    "^manichaeanhundred": "\x00-\U00010aee\U00010af0-\U0010ffff",
    "^manichaeankaph": "\x00-\U00010acf\U00010ad3-\U0010ffff",
    "^manichaeanlamedh": "\x00-\U00010ad2\U00010ad4-\U0010ffff",
    "^manichaeanmem": "\x00-\U00010ad5\U00010ad7-\U0010ffff",
    "^manichaeannun": "\x00-\U00010ad6\U00010ad8-\U0010ffff",
    "^manichaeanone": "\x00-\U00010aea\U00010aec-\U0010ffff",
    "^manichaeanpe": "\x00-\U00010ada\U00010add-\U0010ffff",
    "^manichaeanqoph": "\x00-\U00010add\U00010ae1-\U0010ffff",
    "^manichaeanresh": "\x00-\U00010ae0\U00010ae2-\U0010ffff",
    "^manichaeansadhe": "\x00-\U00010adc\U00010ade-\U0010ffff",
    "^manichaeansamekh": "\x00-\U00010ad7\U00010ad9-\U0010ffff",
    "^manichaeantaw": "\x00-\U00010ae3\U00010ae5-\U0010ffff",
    "^manichaeanten": "\x00-\U00010aec\U00010aee-\U0010ffff",
    "^manichaeanteth": "\x00-\U00010acd\U00010acf-\U0010ffff",
    "^manichaeanthamedh": "\x00-\U00010ad4\U00010ad6-\U0010ffff",
    "^manichaeantwenty": "\x00-\U00010aed\U00010aef-\U0010ffff",
    "^manichaeanwaw": "\x00-\U00010ac6\U00010ac8-\U0010ffff",
    "^manichaeanyodh": "\x00-\U00010ace\U00010ad0-\U0010ffff",
    "^manichaeanzayin": "\x00-\U00010ac8\U00010acb-\U0010ffff",
    "^meem": "\x00-\u0644\u0646-\u0764\u0767-\u08a6\u08a8-\U0010ffff",
    "^mim": "\x00-\u0720\u0722-\U0010ffff",
    "^nonjoining": "\u0620\u0622-\u063f\u0641-\u064a\u066e-\u066f\u0671-\u0673\u0675-\u06d3\u06d5\u06ee-\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u077f\u0860-\u086a\u0870-\u0882\u0886\u0889-\u088e\u08a0-\u08ac\u08ae-\u08c8\U00010ac0-\U00010ac5\U00010ac7\U00010ac9-\U00010aca\U00010acd-\U00010ae1\U00010ae4\U00010aeb-\U00010aef\U00010d02\U00010d09\U00010d19\U00010d1c\U00010d1e\U00010d20\U00010d23\U00010ec2-\U00010ec4",
    "^noon": "\x00-\u0645\u0647-\u06b8\u06bd-\u0766\u076a-\u0888\u088a-\U0010ffff",
    "^nun": "\x00-\u0721\u0723-\U0010ffff",
    "^nya": "\x00-\u06bc\u06be-\U0010ffff",
    "^pe": "\x00-\u0725\u0727-\U0010ffff",
    "^qaf": "\x00-\u0641\u0643-\u066e\u0670-\u06a6\u06a9-\u08a4\u08a6-\u08b4\u08b6-\U0010ffff",
    "^qaph": "\x00-\u0728\u072a-\U0010ffff",
    "^reh": "\x00-\u0630\u0633-\u0690\u069a-\u06ee\u06f0-\u075a\u075c-\u076a\u076d-\u0770\u0772-\u08a9\u08ab-\u08b1\u08b3-\u08b8\u08ba-\U0010ffff",
    "^reversedpe": "\x00-\u0726\u0728-\U0010ffff",
    "^rohingyayeh": "\x00-\u08ab\u08ad-\U0010ffff",
    "^sad": "\x00-\u0634\u0637-\u069c\u069f-\u06fa\u06fc-\u08ae\u08b0-\U0010ffff",
    "^sadhe": "\x00-\u0727\u0729-\U0010ffff",
    "^seen": "\x00-\u0632\u0635-\u0699\u069d-\u06f9\u06fb-\u075b\u075d-\u076c\u076e-\u076f\u0771-\u077c\u077f-\U0010ffff",
    "^semkath": "\x00-\u0722\u0724-\U0010ffff",
    "^shin": "\x00-\u072a\u072c-\U0010ffff",
    "^straightwaw": "\x00-\u08b0\u08b2-\U0010ffff",
    "^swashkaf": "\x00-\u06a9\u06ab-\U0010ffff",
    "^syriacwaw": "\x00-\u0717\u0719-\U0010ffff",
    "^tah": "\x00-\u0636\u0639-\u069e\u06a0-\u088a\u088d-\u08a2\u08a4-\U00010ec2\U00010ec4-\U0010ffff",
    "^taw": "\x00-\u072b\u072d-\U0010ffff",
    "^tehmarbuta": "\x00-\u0628\u062a-\u06bf\u06c1-\u06d4\u06d6-\U0010ffff",
    "^tehmarbutagoal": "\x00-\u06c2\u06c4-\U0010ffff",
    "^teth": "\x00-\u071a\u071d-\U0010ffff",
    "^thinyeh": "\x00-\u0885\u0887-\U0010ffff",
    "^verticaltail": "\x00-\u088d\u088f-\U0010ffff",
    "^waw": "\x00-\u0623\u0625-\u0647\u0649-\u0675\u0678-\u06c3\u06cc-\u06ce\u06d0-\u0777\u077a-\u08aa\u08ac-\U0010ffff",
    "^yeh": "\x00-\u0625\u0627-\u0648\u064b-\u0677\u0679-\u06cf\u06d2-\u0776\u0778-\u08a7\u08aa-\u08b9\u08bb-\U0010ffff",
    "^yehbarree": "\x00-\u06d1\u06d4-\U0010ffff",
    "^yehwithtail": "\x00-\u06cc\u06ce-\U0010ffff",
    "^yudh": "\x00-\u071c\u071e-\U0010ffff",
    "^yudhhe": "\x00-\u071d\u071f-\U0010ffff",
    "^zain": "\x00-\u0718\u071a-\U0010ffff",
    "^zhain": "\x00-\u074c\u074e-\U0010ffff",
    "africanfeh": "\u08bb",
    "africannoon": "\u08bd",
    "africanqaf": "\u08bc\u08c4",
    "ain": "\u0639-\u063a\u06a0\u06fc\u075d-\u075f\u08b3\u08c3",
    "alaph": "\u0710",
    "alef": "\u0622-\u0623\u0625\u0627\u0671-\u0673\u0675\u0773-\u0774\u0870-\u0882",
    "beh": "\u0628\u062a-\u062b\u066e\u0679-\u0680\u0750-\u0756\u08a0-\u08a1\u08b6-\u08b8\u08be-\u08c0",
    "beth": "\u0712\u072d",
    "burushaskiyehbarree": "\u077a-\u077b",
    "dal": "\u062f-\u0630\u0688-\u0690\u06ee\u0759-\u075a\u08ae\U00010ec2",
    "dalathrish": "\u0715-\u0716\u072a\u072f",
    "e": "\u0725",
    "farsiyeh": "\u063d-\u063f\u06cc\u06ce\u0775-\u0776",
    "fe": "\u074f",
    "feh": "\u0641\u06a1-\u06a6\u0760-\u0761\u08a4",
    "finalsemkath": "\u0724",
    "gaf": "\u063b-\u063c\u06a9\u06ab\u06af-\u06b4\u0762-\u0764\u088d\u08b0\u08c2\u08c8",
    "gamal": "\u0713-\u0714\u072e",
    "hah": "\u062c-\u062e\u0681-\u0687\u06bf\u0757-\u0758\u076e-\u076f\u0772\u077c\u088a\u08a2\u08c1\u08c5-\u08c6",
    "hanifirohingyakinnaya": "\U00010d19\U00010d1e\U00010d20\U00010d23",
    "hanifirohingyapa": "\U00010d02\U00010d09\U00010d1c",
    "he": "\u0717",
    "heh": "\u0647",
    "hehgoal": "\u06c1-\u06c2",
    "heth": "\u071a",
    "kaf": "\u0643\u06ac-\u06ae\u077f\u08b4\U00010ec4",
    "kaph": "\u071f",
    "kashmiriyeh": "\u0620",
    "khaph": "\u074e",
    "knottedheh": "\u06be\u06ff",
    "lam": "\u0644\u06b5-\u06b8\u076a\u08a6\u08c7",
    "lamadh": "\u0720",
    "malayalambha": "\u0866",
    "malayalamja": "\u0861",
    "malayalamlla": "\u0868",
    "malayalamllla": "\u0869",
    "malayalamnga": "\u0860",
    "malayalamnna": "\u0864",
    "malayalamnnna": "\u0865",
    "malayalamnya": "\u0862",
    "malayalamra": "\u0867",
    "malayalamssa": "\u086a",
    "malayalamtta": "\u0863",
    "manichaeanaleph": "\U00010ac0",
    "manichaeanayin": "\U00010ad9-\U00010ada",
    "manichaeanbeth": "\U00010ac1-\U00010ac2",
    "manichaeandaleth": "\U00010ac5",
    "manichaeandhamedh": "\U00010ad4",
    "manichaeanfive": "\U00010aec",
    "manichaeangimel": "\U00010ac3-\U00010ac4",
    "manichaeanheth": "\U00010acd",
    "manichaeanhundred": "\U00010aef",
    "manichaeankaph": "\U00010ad0-\U00010ad2",
    "manichaeanlamedh": "\U00010ad3",
    "manichaeanmem": "\U00010ad6",
    "manichaeannun": "\U00010ad7",
    "manichaeanone": "\U00010aeb",
    "manichaeanpe": "\U00010adb-\U00010adc",
    "manichaeanqoph": "\U00010ade-\U00010ae0",
    "manichaeanresh": "\U00010ae1",
    "manichaeansadhe": "\U00010add",
    "manichaeansamekh": "\U00010ad8",
    "manichaeantaw": "\U00010ae4",
    "manichaeanten": "\U00010aed",
    "manichaeanteth": "\U00010ace",
    "manichaeanthamedh": "\U00010ad5",
    "manichaeantwenty": "\U00010aee",
    "manichaeanwaw": "\U00010ac7",
    "manichaeanyodh": "\U00010acf",
    "manichaeanzayin": "\U00010ac9-\U00010aca",
    "meem": "\u0645\u0765-\u0766\u08a7",
    "mim": "\u0721",
    "nonjoining": "\x00-\u061f\u0621\u0640\u064b-\u066d\u0670\u0674\u06d4\u06d6-\u06ed\u06f0-\u06f9\u06fd-\u06fe\u0700-\u070f\u0711\u0730-\u074c\u0780-\u085f\u086b-\u086f\u0883-\u0885\u0887-\u0888\u088f-\u089f\u08ad\u08c9-\U00010abf\U00010ac6\U00010ac8\U00010acb-\U00010acc\U00010ae2-\U00010ae3\U00010ae5-\U00010aea\U00010af0-\U00010d01\U00010d03-\U00010d08\U00010d0a-\U00010d18\U00010d1a-\U00010d1b\U00010d1d\U00010d1f\U00010d21-\U00010d22\U00010d24-\U00010ec1\U00010ec5-\U0010ffff",
    "noon": "\u0646\u06b9-\u06bc\u0767-\u0769\u0889",
    "nun": "\u0722",
    "nya": "\u06bd",
    "pe": "\u0726",
    "qaf": "\u0642\u066f\u06a7-\u06a8\u08a5\u08b5",
    "qaph": "\u0729",
    "reh": "\u0631-\u0632\u0691-\u0699\u06ef\u075b\u076b-\u076c\u0771\u08aa\u08b2\u08b9",
    "reversedpe": "\u0727",
    "rohingyayeh": "\u08ac",
    "sad": "\u0635-\u0636\u069d-\u069e\u06fb\u08af",
    "sadhe": "\u0728",
    "seen": "\u0633-\u0634\u069a-\u069c\u06fa\u075c\u076d\u0770\u077d-\u077e",
    "semkath": "\u0723",
    "shin": "\u072b",
    "straightwaw": "\u08b1",
    "swashkaf": "\u06aa",
    "syriacwaw": "\u0718",
    "tah": "\u0637-\u0638\u069f\u088b-\u088c\u08a3\U00010ec3",
    "taw": "\u072c",
    "tehmarbuta": "\u0629\u06c0\u06d5",
    "tehmarbutagoal": "\u06c3",
    "teth": "\u071b-\u071c",
    "thinyeh": "\u0886",
    "verticaltail": "\u088e",
    "waw": "\u0624\u0648\u0676-\u0677\u06c4-\u06cb\u06cf\u0778-\u0779\u08ab",
    "yeh": "\u0626\u0649-\u064a\u0678\u06d0-\u06d1\u0777\u08a8-\u08a9\u08ba",
    "yehbarree": "\u06d2-\u06d3",
    "yehwithtail": "\u06cd",
    "yudh": "\u071d",
    "yudhhe": "\u071e",
    "zain": "\u0719",
    "zhain": "\u074d"
}
ascii_joining_group: dict[str, str] = {
    "^africanfeh": "\x00-\U0010ffff",
    "^africannoon": "\x00-\U0010ffff",
    "^africanqaf": "\x00-\U0010ffff",
    "^ain": "\x00-\U0010ffff",
    "^alaph": "\x00-\U0010ffff",
    "^alef": "\x00-\U0010ffff",
    "^beh": "\x00-\U0010ffff",
    "^beth": "\x00-\U0010ffff",
    "^burushaskiyehbarree": "\x00-\U0010ffff",
    "^dal": "\x00-\U0010ffff",
    "^dalathrish": "\x00-\U0010ffff",
    "^e": "\x00-\U0010ffff",
    "^farsiyeh": "\x00-\U0010ffff",
    "^fe": "\x00-\U0010ffff",
    "^feh": "\x00-\U0010ffff",
    "^finalsemkath": "\x00-\U0010ffff",
    "^gaf": "\x00-\U0010ffff",
    "^gamal": "\x00-\U0010ffff",
    "^hah": "\x00-\U0010ffff",
    "^hanifirohingyakinnaya": "\x00-\U0010ffff",
    "^hanifirohingyapa": "\x00-\U0010ffff",
    "^he": "\x00-\U0010ffff",
    "^heh": "\x00-\U0010ffff",
    "^hehgoal": "\x00-\U0010ffff",
    "^heth": "\x00-\U0010ffff",
    "^kaf": "\x00-\U0010ffff",
    "^kaph": "\x00-\U0010ffff",
    "^kashmiriyeh": "\x00-\U0010ffff",
    "^khaph": "\x00-\U0010ffff",
    "^knottedheh": "\x00-\U0010ffff",
    "^lam": "\x00-\U0010ffff",
    "^lamadh": "\x00-\U0010ffff",
    "^malayalambha": "\x00-\U0010ffff",
    "^malayalamja": "\x00-\U0010ffff",
    "^malayalamlla": "\x00-\U0010ffff",
    "^malayalamllla": "\x00-\U0010ffff",
    "^malayalamnga": "\x00-\U0010ffff",
    "^malayalamnna": "\x00-\U0010ffff",
    "^malayalamnnna": "\x00-\U0010ffff",
    "^malayalamnya": "\x00-\U0010ffff",
    "^malayalamra": "\x00-\U0010ffff",
    "^malayalamssa": "\x00-\U0010ffff",
    "^malayalamtta": "\x00-\U0010ffff",
    "^manichaeanaleph": "\x00-\U0010ffff",
    "^manichaeanayin": "\x00-\U0010ffff",
    "^manichaeanbeth": "\x00-\U0010ffff",
    "^manichaeandaleth": "\x00-\U0010ffff",
    "^manichaeandhamedh": "\x00-\U0010ffff",
    "^manichaeanfive": "\x00-\U0010ffff",
    "^manichaeangimel": "\x00-\U0010ffff",
    "^manichaeanheth": "\x00-\U0010ffff",
    "^manichaeanhundred": "\x00-\U0010ffff",
    "^manichaeankaph": "\x00-\U0010ffff",
    "^manichaeanlamedh": "\x00-\U0010ffff",
    "^manichaeanmem": "\x00-\U0010ffff",
    "^manichaeannun": "\x00-\U0010ffff",
    "^manichaeanone": "\x00-\U0010ffff",
    "^manichaeanpe": "\x00-\U0010ffff",
    "^manichaeanqoph": "\x00-\U0010ffff",
    "^manichaeanresh": "\x00-\U0010ffff",
    "^manichaeansadhe": "\x00-\U0010ffff",
    "^manichaeansamekh": "\x00-\U0010ffff",
    "^manichaeantaw": "\x00-\U0010ffff",
    "^manichaeanten": "\x00-\U0010ffff",
    "^manichaeanteth": "\x00-\U0010ffff",
    "^manichaeanthamedh": "\x00-\U0010ffff",
    "^manichaeantwenty": "\x00-\U0010ffff",
    "^manichaeanwaw": "\x00-\U0010ffff",
    "^manichaeanyodh": "\x00-\U0010ffff",
    "^manichaeanzayin": "\x00-\U0010ffff",
    "^meem": "\x00-\U0010ffff",
    "^mim": "\x00-\U0010ffff",
    "^nonjoining": "",
    "^noon": "\x00-\U0010ffff",
    "^nun": "\x00-\U0010ffff",
    "^nya": "\x00-\U0010ffff",
    "^pe": "\x00-\U0010ffff",
    "^qaf": "\x00-\U0010ffff",
    "^qaph": "\x00-\U0010ffff",
    "^reh": "\x00-\U0010ffff",
    "^reversedpe": "\x00-\U0010ffff",
    "^rohingyayeh": "\x00-\U0010ffff",
    "^sad": "\x00-\U0010ffff",
    "^sadhe": "\x00-\U0010ffff",
    "^seen": "\x00-\U0010ffff",
    "^semkath": "\x00-\U0010ffff",
    "^shin": "\x00-\U0010ffff",
    "^straightwaw": "\x00-\U0010ffff",
    "^swashkaf": "\x00-\U0010ffff",
    "^syriacwaw": "\x00-\U0010ffff",
    "^tah": "\x00-\U0010ffff",
    "^taw": "\x00-\U0010ffff",
    "^tehmarbuta": "\x00-\U0010ffff",
    "^tehmarbutagoal": "\x00-\U0010ffff",
    "^teth": "\x00-\U0010ffff",
    "^thinyeh": "\x00-\U0010ffff",
    "^verticaltail": "\x00-\U0010ffff",
    "^waw": "\x00-\U0010ffff",
    "^yeh": "\x00-\U0010ffff",
    "^yehbarree": "\x00-\U0010ffff",
    "^yehwithtail": "\x00-\U0010ffff",
    "^yudh": "\x00-\U0010ffff",
    "^yudhhe": "\x00-\U0010ffff",
    "^zain": "\x00-\U0010ffff",
    "^zhain": "\x00-\U0010ffff",
    "africanfeh": "",
    "africannoon": "",
    "africanqaf": "",
    "ain": "",
    "alaph": "",
    "alef": "",
    "beh": "",
    "beth": "",
    "burushaskiyehbarree": "",
    "dal": "",
    "dalathrish": "",
    "e": "",
    "farsiyeh": "",
    "fe": "",
    "feh": "",
    "finalsemkath": "",
    "gaf": "",
    "gamal": "",
    "hah": "",
    "hanifirohingyakinnaya": "",
    "hanifirohingyapa": "",
    "he": "",
    "heh": "",
    "hehgoal": "",
    "heth": "",
    "kaf": "",
    "kaph": "",
    "kashmiriyeh": "",
    "khaph": "",
    "knottedheh": "",
    "lam": "",
    "lamadh": "",
    "malayalambha": "",
    "malayalamja": "",
    "malayalamlla": "",
    "malayalamllla": "",
    "malayalamnga": "",
    "malayalamnna": "",
    "malayalamnnna": "",
    "malayalamnya": "",
    "malayalamra": "",
    "malayalamssa": "",
    "malayalamtta": "",
    "manichaeanaleph": "",
    "manichaeanayin": "",
    "manichaeanbeth": "",
    "manichaeandaleth": "",
    "manichaeandhamedh": "",
    "manichaeanfive": "",
    "manichaeangimel": "",
    "manichaeanheth": "",
    "manichaeanhundred": "",
    "manichaeankaph": "",
    "manichaeanlamedh": "",
    "manichaeanmem": "",
    "manichaeannun": "",
    "manichaeanone": "",
    "manichaeanpe": "",
    "manichaeanqoph": "",
    "manichaeanresh": "",
    "manichaeansadhe": "",
    "manichaeansamekh": "",
    "manichaeantaw": "",
    "manichaeanten": "",
    "manichaeanteth": "",
    "manichaeanthamedh": "",
    "manichaeantwenty": "",
    "manichaeanwaw": "",
    "manichaeanyodh": "",
    "manichaeanzayin": "",
    "meem": "",
    "mim": "",
    "nonjoining": "\x00-\U0010ffff",
    "noon": "",
    "nun": "",
    "nya": "",
    "pe": "",
    "qaf": "",
    "qaph": "",
    "reh": "",
    "reversedpe": "",
    "rohingyayeh": "",
    "sad": "",
    "sadhe": "",
    "seen": "",
    "semkath": "",
    "shin": "",
    "straightwaw": "",
    "swashkaf": "",
    "syriacwaw": "",
    "tah": "",
    "taw": "",
    "tehmarbuta": "",
    "tehmarbutagoal": "",
    "teth": "",
    "thinyeh": "",
    "verticaltail": "",
    "waw": "",
    "yeh": "",
    "yehbarree": "",
    "yehwithtail": "",
    "yudh": "",
    "yudhhe": "",
    "zain": "",
    "zhain": ""
}
